.. image:: https://raw.githubusercontent.com/aranzgeo/steno3dpy/master/docs/images/steno3d_logo.png
    :width: 240
    :align: center
    :target: https://steno3d.com/
    :alt: Steno3D

|
|

.. image:: https://travis-ci.org/aranzgeo/steno3dpy.svg?branch=master
    :target: https://travis-ci.org/aranzgeo/steno3dpy

.. image:: https://img.shields.io/badge/license-MIT-blue.svg
    :alt: MIT License
    :target: https://github.com/aranzgeo/steno3dpy/blob/master/LICENSE

.. image:: https://img.shields.io/badge/download-PyPI-yellow.svg
    :target: https://pypi.python.org/pypi/steno3d

Welcome to the Python client library for `Steno3D <https://steno3d.com>`_
by `ARANZ Geo Limited <https://www.aranzgeo.com>`_. Explore and collaborate on your 3D data!

Demo Video
----------

.. image:: https://img.youtube.com/vi/M6C6SRwn7bg/0.jpg
    :target: https://www.youtube.com/watch?v=M6C6SRwn7bg
    :alt: steno3dpy demo

Quickstart
----------

If you have not yet installed `Steno3D <https://steno3d.com>`_, simply

.. code:: bash

    pip install steno3d

You also need to `sign up for a Steno3D account <https://steno3d.com/signup>`_.
From there, you can `request a developer API key <https://steno3d.com/settings/developer>`_.

At that point, you can

.. code:: python

    import steno3d
    steno3d.login()

then start building your 3D project. API documentation is available on
`online <https://steno3d.com/docs>`_. Tutorials and
Examples are available as `Jupyter notebooks <https://github.com/aranzgeo/steno3d-notebooks>`_.
Class documentation can also be accessed in the IPython environment
with `?` and tab completion.

.. image:: https://raw.githubusercontent.com/aranzgeo/steno3dpy/master/docs/images/steno3dpy_screenshot.png
    :width: 100%
    :align: center
    :alt: Steno3D in action
    :target: https://steno3d.com/

The latest version of Steno3D is 0.3.5. Detailed release notes are available
on `github <https://github.com/aranzgeo/steno3dpy/releases>`_.
